#
# spec file for package apk-tools
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2024, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 2
%define soname 2_14_0
%define libname libapk%{soname}
Name:           apk-tools
Version:        2.14.4
Release:        1.2
Summary:        Alpine package manager
License:        GPL-2.0-or-later
Group:          System/Packages
URL:            https://git.alpinelinux.org/apk-tools/
Source:         %{name}-%{version}.tar.xz
BuildRequires:  lua53-devel
BuildRequires:  lua53-zlib
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  scdoc
BuildRequires:  pkgconfig(libcrypto)
Provides:       bundled(libfetch)

%description
Alpine Package Keeper (apk) is a package manager originally built for
Alpine Linux, but now used by several other distributions as well.

%package -n %{libname}
Summary:        Library for the Alpine package manager
Group:          System/Libraries

%description -n %{libname}
Alpine Package Keeper (apk) is a package manager originally built for
Alpine Linux, but now used by several other distributions as well.

Library for the Alpine package manager.

%package -n lua53-apk
Summary:        Lua module for apk-tools
Group:          System/Packages
Requires:       %name = %version-%release
Requires:       lua53

%description -n lua53-apk
Lua module for apk-tools.

%package -n apk-devel
Summary:        Development files for apk
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description -n apk-devel
Alpine Package Keeper (apk) is a package manager originally built for
Alpine Linux, but now used by several other distributions as well.

This package contains headers and libraries required to build applications
that use libapk.

%prep
%setup -q

%build
%make_build

%install
%make_install \
     SBINDIR=%{_sbindir} \
     LIBDIR=%{_libdir} \
     LUA_LIBDIR=%{_libdir}/lua/5.3 \
     DOCDIR=%{_docdir}/apk-tools \
     PKGCONFIGDIR=%{_libdir}/pkgconfig

rm -v %{buildroot}%{_libdir}/libapk.a
# remove spurious exec permissions from manpages
find %{buildroot}%{_mandir} -type f | xargs  chmod -x

%ldconfig_scriptlets -n %{libname}

%files
%license LICENSE
%doc README.md
%{_sbindir}/apk
%{_mandir}/man8/apk.8%{?ext_man}
%{_mandir}/man[5,8]/apk-*.[5,8]%{?ext_man}

%files -n %{libname}
%{_libdir}/libapk.so.%{sover}*

%files -n lua53-apk
%{_libdir}/lua/5.3/apk.so

%files -n apk-devel
%dir %{_includedir}/apk
%{_includedir}/apk/apk_*.h
%{_includedir}/apk/help.h
%{_libdir}/libapk.so
%{_libdir}/pkgconfig/apk.pc

%changelog
* Sat Jun 22 2024 Martin Hauke <mardnh@gmx.de>
- Build lua module
- Update to version 2.14.4
  * db: fix creation of missing directories
  * index: do not print message if outputting file to stdout
  * pkg: accept broken fpm generated packages with a warning
  * pkg: allow multiple data sections with a warning
  * pkg: fix index speed regression
  * pkg: always use real digest, openssl-fips module crashes
    otherwise
- Update to version 2.14.3
  * io: fix gunzip mpart handling regression
- Update to version 2.14.2
  * list: fix -P with filter
  * verify: synchronize with git master
  * db: refactor apk_package.filename to index
  * pkg: clean up and simplify code
  * io: simplify mpart and error handling
  * io: fix apk_istream_get_max non-complete reads
  * doc: apk(8) document environment and libfetch config
  * doc: apk(8) add FILES section, speak of world constraints
  * list: consider only tag appropriate versions in upgradable
  * doc: add(8), del(8), world(5) speak of world constraints
  * doc: apk(8) document --force-broken-world better
  * pkg: reorder struct apk_package fields for size
  * doc: apk-search(8) is case insensitive
  * doc: mention /etc/apk/repositories.d/*.list
  * doc: fix tagged package explaination
  * doc: mention apk-world(5) in apk-del(8) and apk-add(8)
  * doc: mention apk-repositories(5) in apk-search(8)
  * hash: remove unused code
  * db: remove dynamic allocations from reverse name calculation
  * version: calculate installed column size dynamically
  * build: require gnu11 and guarantee assert.h included from
    apk_defines.h
  * db, selected applets: allow --arch to override database
    architecture
  * commit: consider install_if chains correctly in error analysis
  * solver: purge conflicts also via provided name
  * audit: fix reporting of directory db details
- Update to version 2.14.1
  * apk: remove empty arguments for add/del/dot/fix only
  * tar: set file mtime to package mtime in scripts.tar
  * db: calculate cache index hash from full url
  * doc: remove args from apk info --test and --check
  * doc: document -t short option for apk info
  * list: add support for --quiet to only print pkgname
  * apk-audit: exclude busybox-extras with
  - -ignore-busybox-symlinks
  * apk-cache(5): add missing word
  * apk-repositories(5): fix cache path
  * libfetch: remove a set-but-not-uswed variable
  * libfetch: support EAI_ADDRFAMILY error, correct two error
    messages
  * doc/apk-policy: fix documentation about sort order
  * db, print: describe process exit status better
  * db: handle waitpid returning EINTR
  * commit: properly propagate install-if status in error
    analysis
  * define APK_DEFAULT_ARCH for loongarch targets
  * pkg: invalidate sorted installed packages cache on package
    uninstall
  * fetch: prefer fetching package with the concrete name
  * del: fix up previous commit
  * del: fix --rdepends
* Sun Mar 10 2024 Martin Hauke <mardnh@gmx.de>
- Initial package, version 2.14.0
